==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Ana sayfa',
'articles' => 'Makaleler',
'articles_auteur' => 'Bu yazar&#305;n makaleleri',
'articles_populaires' => 'En pop&uuml;ler makaleler',
'articles_rubrique' => 'Bu b&ouml;l&uuml;m&uuml;n makaleleri',
'aucun_article' => 'Bu adreste makale yok',
'aucun_auteur' => 'Bu adreste yazar yok',
'aucun_site' => 'Bu adreste site yok',
'aucune_breve' => 'Bu adreste k&#305;sa haber yok',
'aucune_rubrique' => 'Bu adreste b&ouml;l&uuml;m yok',
'autres' => 'Di&#287;er',
'autres_breves' => 'Di&#287;er k&#305;sa haberler',
'autres_groupes_mots_clefs' => 'Di&#287;er anahtar s&ouml;zc&uuml;k gruplar&#305;',
'autres_sites' => 'Di&#287;er siteler',

// B
'bonjour' => 'Merhaba',
'breves' => 'K&#305;sa haberler',

// C
'commenter_site' => 'Bu siteye yorum ekle',
'copie_document_impossible' => 'Belgeyi kopyalamak olanaks&#305;z',

// D
'date' => 'Tarih',
'dernier_ajout' => 'Son eklenen',
'dernieres_breves' => 'Son eklenen k&#305;sa haberler',
'derniers_articles' => 'Son eklenen makaleler',
'derniers_commentaires' => 'Son eklenen yorumlar',
'derniers_messages_forum' => 'Forumlarda yay&#305;nlanan son mesajlar',
'documents_interdits_forum' => 'Forumda yasak olan belgeler',

// E
'edition_mode_texte' => 'Metin &#351;eklinde de&#287;i&#351;tir',
'en_reponse' => 'Yan&#305;tt&#305;r&nbsp;:',
'en_resume' => '&Ouml;zet',
'envoyer_message' => 'Bir mesaj g&ouml;nder',
'espace_prive' => '&Ouml;zel alan',

// F
'formats_acceptes' => 'Kab&ucirc;l edilen bi&ccedil;emler : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Site hiyerar&#351;isi',

// J
'jours' => 'g&uuml;n',

// L
'lien_connecter' => 'Ba&#287;lan',

// M
'meme_auteur' => 'Ayn&#305; yazardan',
'meme_rubrique' => 'Ayn&#305; b&ouml;l&uuml;mde',
'memes_auteurs' => 'Ayn&#305; yazarlardan',
'message' => '&#304;leti',
'messages_forum' => 'Forum mesajlar&#305;',
'messages_recents' => 'Son forum mesajlar&#305;',
'mots_clefs' => 'Anahtar s&ouml;zc&uuml;k',
'mots_clefs_meme_groupe' => 'Ayn&#305; grupta anahtar s&ouml;zc&uuml;k',

// N
'navigation' => 'Gezinti',
'nom' => 'Soyad&#305;',
'nouveautes' => 'Yenilikler',
'nouveautes_web' => 'Web\'deki yenilikler',
'nouveaux_articles' => 'Yeni makaleler',
'nouvelles_breves' => 'Yeni k&#305;sa haberler',

// P
'page_precedente' => '&ouml;nceki sayfa',
'page_suivante' => 'sonraki sayfa',
'par_auteur' => 'yazan',
'participer_site' => 'Bu siteye katk&#305;da bulunabilir ve a&#351;a&#287;&#305;ya kay&#305;t olarak kendi makalelerinizi &ouml;nerebilirsiniz. Bu durumda hemen sitenin &ouml;zel alan&#305;na girmenizi sa&#287;layacak kodlar&#305; i&ccedil;eren bir mesaj al&#305;rs&#305;n&#305;z.',
'plan_site' => 'Site plan&#305;',
'popularite' => 'Pop&uuml;lerlik',
'poster_message' => 'Bir mesaj g&ouml;nder',
'proposer_site' => 'Bu b&ouml;l&uuml;me eklenecek bir site &ouml;nerebilirsiniz&nbsp;:',

// R
'repondre_article' => 'Bu makaleyi yan&#305;tla',
'repondre_breve' => 'Bu k&#305;sa haberi yan&#305;tla',
'repondre_message' => 'Bu mesaj&#305; yan&#305;tla',
'resultats_recherche' => 'Arama sonu&ccedil;lar&#305;',
'retour_debut_forums' => 'Forumlar&#305;n ba&#351;&#305;na d&ouml;n',
'rubrique' => 'B&ouml;l&uuml;m',
'rubriques' => 'B&ouml;l&uuml;mler',

// S
'signatures_petition' => '&#304;mzalar',
'site_realise_avec_spip' => 'SPIP ile ger&ccedil;ekle&#351;tirilmi&#351; site',
'sites_web' => 'web sitesi',
'sous_rubriques' => 'Alt-b&ouml;l&uuml;mler',
'spam' => 'Spam',
'suite' => 'devam&#305;',
'sur_web' => 'Web\'de',
'syndiquer_rubrique' => 'Bu b&ouml;l&uuml;m&uuml; payla&#351;',
'syndiquer_site' => 'T&uuml;m siteyi payla&#351;',

// T
'texte_lettre_information' => 'Sitenin bilgilendirme mektubu',
'texte_lettre_information_2' => 'Bu mektup belirtilen tarihten beri eklenen makale ve k&#305;sa haberleri listeler',

// V
'ver_imprimer' => 'Bas&#305;lacak s&uuml;r&uuml;m',
'voir_en_ligne' => '&Ccedil;evrimi&ccedil;i g&ouml;r&uuml;nt&uuml;le',
'voir_squelette' => 'bu sayfan&#305;n iskeletini g&ouml;ster'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Ana sayfa',
'article' => 'Article', # NEW
'articles' => 'Makaleler',
'articles_auteur' => 'Bu yazar&#305;n makaleleri',
'articles_populaires' => 'En pop&uuml;ler makaleler',
'articles_rubrique' => 'Bu b&ouml;l&uuml;m&uuml;n makaleleri',
'aucun_article' => 'Bu adreste makale yok',
'aucun_auteur' => 'Bu adreste yazar yok',
'aucun_site' => 'Bu adreste site yok',
'aucune_breve' => 'Bu adreste k&#305;sa haber yok',
'aucune_rubrique' => 'Bu adreste b&ouml;l&uuml;m yok',
'auteur' => 'Auteur', # NEW
'autres' => 'Di&#287;er',
'autres_breves' => 'Di&#287;er k&#305;sa haberler',
'autres_groupes_mots_clefs' => 'Di&#287;er anahtar s&ouml;zc&uuml;k gruplar&#305;',
'autres_sites' => 'Di&#287;er siteler',

// B
'bonjour' => 'Merhaba',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'K&#305;sa haberler',

// C
'commenter_site' => 'Bu siteye yorum ekle',
'copie_document_impossible' => 'Belgeyi kopyalamak olanaks&#305;z',

// D
'date' => 'Tarih',
'dernier_ajout' => 'Son eklenen',
'dernieres_breves' => 'Son eklenen k&#305;sa haberler',
'derniers_articles' => 'Son eklenen makaleler',
'derniers_commentaires' => 'Son eklenen yorumlar',
'derniers_messages_forum' => 'Forumlarda yay&#305;nlanan son mesajlar',
'documents_interdits_forum' => 'Forumda yasak olan belgeler',

// E
'edition_mode_texte' => 'Metin &#351;eklinde de&#287;i&#351;tir',
'en_reponse' => 'Yan&#305;tt&#305;r&nbsp;:',
'en_resume' => '&Ouml;zet',
'envoyer_message' => 'Bir mesaj g&ouml;nder',
'espace_prive' => '&Ouml;zel alan',

// F
'formats_acceptes' => 'Kab&ucirc;l edilen bi&ccedil;emler : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Site hiyerar&#351;isi',

// J
'jours' => 'g&uuml;n',

// L
'lien_connecter' => 'Ba&#287;lan',

// M
'meme_auteur' => 'Ayn&#305; yazardan',
'meme_rubrique' => 'Ayn&#305; b&ouml;l&uuml;mde',
'memes_auteurs' => 'Ayn&#305; yazarlardan',
'message' => '&#304;leti',
'messages_forum' => 'Forum mesajlar&#305;',
'messages_recents' => 'Son forum mesajlar&#305;',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Anahtar s&ouml;zc&uuml;k',
'mots_clefs_meme_groupe' => 'Ayn&#305; grupta anahtar s&ouml;zc&uuml;k',

// N
'navigation' => 'Gezinti',
'nom' => 'Soyad&#305;',
'nouveautes' => 'Yenilikler',
'nouveautes_web' => 'Web\'deki yenilikler',
'nouveaux_articles' => 'Yeni makaleler',
'nouvelles_breves' => 'Yeni k&#305;sa haberler',

// P
'page_precedente' => '&ouml;nceki sayfa',
'page_suivante' => 'sonraki sayfa',
'par_auteur' => 'yazan',
'participer_site' => 'Bu siteye katk&#305;da bulunabilir ve a&#351;a&#287;&#305;ya kay&#305;t olarak kendi makalelerinizi &ouml;nerebilirsiniz. Bu durumda hemen sitenin &ouml;zel alan&#305;na girmenizi sa&#287;layacak kodlar&#305; i&ccedil;eren bir mesaj al&#305;rs&#305;n&#305;z.',
'plan_site' => 'Site plan&#305;',
'popularite' => 'Pop&uuml;lerlik',
'poster_message' => 'Bir mesaj g&ouml;nder',
'proposer_site' => 'Bu b&ouml;l&uuml;me eklenecek bir site &ouml;nerebilirsiniz&nbsp;:',

// R
'repondre_article' => 'Bu makaleyi yan&#305;tla',
'repondre_breve' => 'Bu k&#305;sa haberi yan&#305;tla',
'repondre_message' => 'Bu mesaj&#305; yan&#305;tla',
'resultats_recherche' => 'Arama sonu&ccedil;lar&#305;',
'retour_debut_forums' => 'Forumlar&#305;n ba&#351;&#305;na d&ouml;n',
'rubrique' => 'B&ouml;l&uuml;m',
'rubriques' => 'B&ouml;l&uuml;mler',

// S
'signatures_petition' => '&#304;mzalar',
'site_realise_avec_spip' => 'SPIP ile ger&ccedil;ekle&#351;tirilmi&#351; site',
'sites_web' => 'web sitesi',
'sous_rubriques' => 'Alt-b&ouml;l&uuml;mler',
'spam' => 'Spam',
'suite' => 'devam&#305;',
'sur_web' => 'Web\'de',
'syndiquer_rubrique' => 'Bu b&ouml;l&uuml;m&uuml; payla&#351;',
'syndiquer_site' => 'T&uuml;m siteyi payla&#351;',

// T
'texte_lettre_information' => 'Sitenin bilgilendirme mektubu',
'texte_lettre_information_2' => 'Bu mektup belirtilen tarihten beri eklenen makale ve k&#305;sa haberleri listeler',

// V
'ver_imprimer' => 'Bas&#305;lacak s&uuml;r&uuml;m',
'voir_en_ligne' => '&Ccedil;evrimi&ccedil;i g&ouml;r&uuml;nt&uuml;le',
'voir_squelette' => 'bu sayfan&#305;n iskeletini g&ouml;ster'
);

?>
